@@ -4,12 +4,15 @@ from .rainbow_npy import *
 from .rainbow_FITS import *
 from .text import *
 
+# some particular instruments
+from .nres import *
+from .atoca import *
+
 # some individual-ish folks
 from .espinoza import *
 from .dossantos import *
 from .feinstein import *
 from .schlawin import *
-from .radica import *
 from .coloumbe import *
 
 
@@ -67,5 +70,9 @@ def guess_reader(filepath, format=None):
         filenames[0], "*.csv"
     ):
         return from_text
+    elif fnmatch.fnmatch(filenames[0], "*e92-1d.fits") or fnmatch.fnmatch(
+        filenames[0], "*e92-1d.fits.fz"
+    ):
+        return from_nres
     else:
         raise RuntimeError(f"🌈 Failed to guess a good reader for {filenames}.")
