@@ -1,4 +1,4 @@
-import os
+import os, pytest
 
 test_directory = "examples/"
 
